@@ -1,6 +1,6 @@
 context("checkInterrupts")
 
-test_that("check_interrupts = TRUE works with queries < 1 second (#244)", {
+test_that("check_interrupts = TRUE works with queries < 1 second", {
   con <- postgresDefault(check_interrupts = TRUE)
   time <- system.time(
     expect_equal(dbGetQuery(con, "SELECT pg_sleep(0.2), 'foo' AS x")$x, "foo")
@@ -9,6 +9,15 @@ test_that("check_interrupts = TRUE works with queries < 1 second (#244)", {
   dbDisconnect(con)
 })
 
+test_that("check_interrupts = TRUE works with queries > 1 second (#244)", {
+  con <- postgresDefault(check_interrupts = TRUE)
+  time <- system.time(
+    expect_equal(dbGetQuery(con, "SELECT pg_sleep(2), 'foo' AS x")$x, "foo")
+  )
+  expect_gt(time[["elapsed"]], 1.5)
+  dbDisconnect(con)
+})
+
 test_that("check_interrupts = TRUE interrupts immediately (#336)", {
   skip_if_not(postgresHasDefault())
   skip_if(Sys.getenv("R_COVR") != "")
@@ -20,6 +29,8 @@ test_that("check_interrupts = TRUE interrupts immediately (#336)", {
   session$run(function() {
     library(RPostgres)
     .GlobalEnv$conn <- postgresDefault(check_interrupts = TRUE)
+    .GlobalEnv$connPid <- dbGetQuery(.GlobalEnv$conn, "SELECT pg_backend_pid() AS pid")$pid
+    .GlobalEnv$checkConn <- postgresDefault()
     invisible()
   })
 
@@ -31,8 +42,13 @@ test_that("check_interrupts = TRUE interrupts immediately (#336)", {
   session$interrupt()
   # Interrupts are slow on Windows, give ample time
   expect_equal(session$poll_process(2000), "ready")
+  session$read()
+
+  queryStatus = session$run(function() {
+    dbGetQuery(.GlobalEnv$checkConn, "SELECT state FROM pg_stat_activity WHERE pid = $1", params = .GlobalEnv$connPid)
+  })
+  expect_equal(queryStatus$state, "idle")
 
-  # Tests for error behavior are brittle
 
   session$close()
 })
